=begin
Copyright 2013, Chris Fullmer
All Rights Reserved

Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

License
This software is distributed under the Smustard End User License Agreement
http://www.smustard.com/eula

Information
Author - Chris Fullmer
Organization - www.ChrisFullmer.com and distributed on www.sketchup.com
Name - Centerpoint Finder
SU Version - 2013, 8, 7


Description
This scipt places a construction point at the centerpoint of an arc, 
even after the arc has been exploded in SketchUp.

Usage
Select two line segments that used to be part of an arc object in SketchUp.  
Then run the plugin from Plugins>Chris Fullmer Tools>Arc CenterPoint Finder

History:
1.0 - 2009-05-11
  * First release
1.1 - 2009-10-27
  * Previously, if in group edit mode, the construction point was not being added into the group.  Not it will be correctly added into the group being edited.
2.0.0 - 2013-4-15
  * Reformatted to be compatible with the SketchUp Extension Warehouse
  * Turned into true Extension
  * Packaged as .rbz
2.0.1 - 2013-4-26
  * Updated the extension code so it now loads and unloads correctly.
2.0.2 = 2013-4-29
  * Updated menus to be compatible and uniform with all my plugins on EW
2.0.3 2013-05-06
  * Fixed menu compatibility with older clf scripts
2.0.4 2013-05-21
  * Another minor menu fix
=end


module CLF_Extensions_NS
  
  module CLF_Arc_Centerpoint_Finder

    require 'sketchup.rb'
    require 'extensions.rb'
    
    NAME = "clf_arc_centerpoint_finder"
    UNAME = "CLF Arc Centerpoint Finder"
    MENU_NAME = "Arc Centerpoint Finder"
    version = "2.0.4"              # EDIT
    desc = 'This plugin adds a Construction Point to the "should-be" centerpoint of an exploded arc or circle.'
    copy_year = "2013"
    author = "Chris Fullmer"
    
#------edit above--------------------------------------------------------------- 

    
    extension = SketchupExtension.new UNAME, NAME+"/"+NAME+"_menus.rb"

    #The name= method sets the name which appears for an extension inside the Extensions Manager dialog.
    extension.name = UNAME

    # The description= method sets the long description which appears beneath an extension inside the Extensions Manager dialog.
    extension.description = desc + "  Access it via Plugins > Chris Fullmer Tools > "+MENU_NAME

    # The version method sets the version which appears beneath an extension inside the Extensions Manager dialog.
    extension.version = version

    # Create an entry in the Extension list that loads a script called
    # stairTools.rb.
    extension.copyright = copy_year
     
    # The creator= method sets the creator string which appears beneath an extension inside the Extensions Manager dialog.
    extension.creator = author

    # The register_extension method is used to register an extension with SketchUp's extension manager (in SketchUp preferences).
    Sketchup.register_extension( extension, true )
    
  end
  
end # module
