# See the loader file for license and author info

module CLF_Extensions_NS

  module CLF_Arc_Centerpoint_Finder

    def self.main
      model = Sketchup.active_model
      sel = model.selection
      ents = model.active_entities
      if sel.length != 2
        UI.messagebox "Please select two lines segments before running this script."
        return
      end

      if sel[0].is_a?(Sketchup::Edge) && sel[0].is_a?( Sketchup::Edge)
        seg1 = sel[0]
        seg2 = sel[1]
        s1p1 = seg1.start.position
        s1p2 = seg1.end.position
        s2p1 = seg2.start.position
        s2p2 = seg2.end.position
        orig_vec1 = seg1.line[1]
        orig_vec2 = seg2.line[1]
        mp1 = Geom.linear_combination 0.5, s1p1, 0.5, s1p2
        mp2 = Geom.linear_combination 0.5, s2p1, 0.5, s2p2
        if orig_vec1.parallel? orig_vec2
          UI.messagebox "Segments are parallel"
          return
        end
        zvec = orig_vec1.cross orig_vec2
        vec1 = orig_vec1.cross zvec
        vec2 = orig_vec2.cross zvec
        
        line1 = [mp1, vec1]
        line2 = [mp2, vec2]
        pt = Geom.intersect_line_line(line1, line2)
        if pt == nil
          puts "pt1 = nil"
          vec1.reverse!
          vec2.reverse!
          line1 = [mp1, vec1]
          line2 = [mp2, vec2]
          pt = Geom.intersect_line_line(line1, line2)
        end
        if pt == nil
          puts "pt2 is nil also."
          UI.messagebox "These segments do not have a centerpoint."
          return
        end
        model.start_operation( "Centerpoint Finder", true )
        ents.add_cpoint pt
        model.commit_operation
      else
        UI.messagebox "Please select two lines segments before running this script."
        return
      end
    end # main
  end #module
end #module

